# mypy-boto3-signer

[![PyPI - mypy-boto3-signer](https://img.shields.io/pypi/v/mypy-boto3-signer.svg?color=blue)](https://pypi.org/project/mypy-boto3-signer)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-signer.svg?color=blue)](https://pypi.org/project/mypy-boto3-signer)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Signer 1.16.28](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/signer.html#Signer) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.0.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-signer](#mypy-boto3-signer)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Signer` service.

```bash
python -m pip install boto3-stubs[signer]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[signer]` in your environment: `python -m pip install 'boto3-stubs[signer]'`

Both type checking and auto-complete should work for `Signer` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[signer]` in your environment: `python -m pip install 'boto3-stubs[signer]'`

Both type checking and auto-complete should work for `Signer` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[signer]` in your environment: `python -m pip install 'boto3-stubs[signer]'`
- Run `mypy` as usual

Type checking should work for `Signer` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[signer]` in your environment: `python -m pip install 'boto3-stubs[signer]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Signer` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`SignerClient` provides annotations for `boto3.client("signer")`.

```python
import boto3

from mypy_boto3_signer import SignerClient

client: SignerClient = boto3.client("signer")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SignerClient = session.client("signer")
```

### Paginators annotations

`mypy_boto3_signer.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_signer import SignerClient
from mypy_boto3_signer.paginator import (
    ListSigningJobsPaginator,
    ListSigningPlatformsPaginator,
    ListSigningProfilesPaginator,
)

client: SignerClient = boto3.client("signer")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_signing_jobs_paginator: ListSigningJobsPaginator = client.get_paginator("list_signing_jobs")
list_signing_platforms_paginator: ListSigningPlatformsPaginator = client.get_paginator("list_signing_platforms")
list_signing_profiles_paginator: ListSigningProfilesPaginator = client.get_paginator("list_signing_profiles")
```


### Waiters annotations

`mypy_boto3_signer.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_signer import SignerClient
from mypy_boto3_signer.waiter import SuccessfulSigningJobWaiter

client: SignerClient = boto3.client("signer")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
successful_signing_job_waiter: SuccessfulSigningJobWaiter = client.get_waiter("successful_signing_job")
```





### Typed dictionations

`mypy_boto3_signer.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_signer.type_defs import (
    AddProfilePermissionResponseTypeDef,
    DescribeSigningJobResponseTypeDef,
    DestinationTypeDef,
    EncryptionAlgorithmOptionsTypeDef,
    GetSigningPlatformResponseTypeDef,
    GetSigningProfileResponseTypeDef,
    HashAlgorithmOptionsTypeDef,
    ListProfilePermissionsResponseTypeDef,
    ListSigningJobsResponseTypeDef,
    ListSigningPlatformsResponseTypeDef,
    ListSigningProfilesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PermissionTypeDef,
    PutSigningProfileResponseTypeDef,
    RemoveProfilePermissionResponseTypeDef,
    S3DestinationTypeDef,
    S3SignedObjectTypeDef,
    S3SourceTypeDef,
    SignatureValidityPeriodTypeDef,
    SignedObjectTypeDef,
    SigningConfigurationOverridesTypeDef,
    SigningConfigurationTypeDef,
    SigningImageFormatTypeDef,
    SigningJobRevocationRecordTypeDef,
    SigningJobTypeDef,
    SigningMaterialTypeDef,
    SigningPlatformOverridesTypeDef,
    SigningPlatformTypeDef,
    SigningProfileRevocationRecordTypeDef,
    SigningProfileTypeDef,
    SourceTypeDef,
    StartSigningJobResponseTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> EncryptionAlgorithmOptionsTypeDef:
    return {
      ...
    }
```
